package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsBrandingAward;
import com.ruoyi.jjh.declaration.entity.BmsCarrierConstructionAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.BmsCarrierConstructionAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsCarrierConstructionAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsCarrierConstructionAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsCarrierConstructionAwardService;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 载体建设奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsCarrierConstructionAwardServiceImpl extends ServiceImpl<BmsCarrierConstructionAwardMapper,BmsCarrierConstructionAward> implements IBmsCarrierConstructionAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询载体建设奖补
     * 
     * @param id 载体建设奖补主键
     * @return 载体建设奖补
     */
    @Override
    public BmsCarrierConstructionAward selectBmsCarrierConstructionAwardById(Long id) {
        return baseMapper.selectBmsCarrierConstructionAwardById(id);
    }

    /**
     * 查询载体建设奖补列表
     * 
     * @param bmsCarrierConstructionAward 载体建设奖补
     * @return 载体建设奖补
     */
    @Override
    public List<BmsCarrierConstructionAward> selectBmsCarrierConstructionAwardList(BmsCarrierConstructionAward bmsCarrierConstructionAward) {
        return baseMapper.selectBmsCarrierConstructionAwardList(bmsCarrierConstructionAward);
    }

    /**
     * 新增载体建设奖补
     * 
     * @param bmsCarrierConstructionAwardAddDto 载体建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsCarrierConstructionAward(BmsCarrierConstructionAwardAddDto bmsCarrierConstructionAwardAddDto) {

        Long enterpriseId = iCommonService.checkEnterprise(bmsCarrierConstructionAwardAddDto.getTyshxydm()
                ,bmsCarrierConstructionAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsCarrierConstructionAwardAddDto.getTyshxydm()
                ,bmsCarrierConstructionAwardAddDto.getTemplateRecordId());
        BmsCarrierConstructionAward bmsCarrierConstructionAward = new BmsCarrierConstructionAward();
        BeanUtil.copyProperties(bmsCarrierConstructionAwardAddDto,bmsCarrierConstructionAward);
        bmsCarrierConstructionAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsCarrierConstructionAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交载体建设奖补申请");
        declarationRecords.setDetailId(bmsCarrierConstructionAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsCarrierConstructionAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //获取某个在线记录id可以添加到项目库的数据
        JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsCarrierConstructionAwardAddDto.getDeclarationId());
        addProject.setStatus(1);
        addProject.setOtherJson(JSONObject.toJSONString(bmsCarrierConstructionAward));
        addProject.setFileJson("{" +
                '"' + "相关佐证资料" + '"' + ":" + '"' + bmsCarrierConstructionAward.getSupportingMaterials() + '"' + ','+
                '"' + "项目工商登记许可" + '"' + ":" + '"' + bmsCarrierConstructionAward.getBusinessLicense() + '"' + ','+
                '"' + "消防验收报告" + '"' + ":" + '"' + bmsCarrierConstructionAward.getFireReport() + '"' +
                "}");
        jProjectService.save(addProject);
        declarationRecords.setJjhProjectId(addProject.getId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    /**
     * 修改载体建设奖补
     * 
     * @param bmsCarrierConstructionAwardUpdateDto 载体建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsCarrierConstructionAward(BmsCarrierConstructionAwardUpdateDto bmsCarrierConstructionAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsCarrierConstructionAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsCarrierConstructionAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsCarrierConstructionAward(bmsCarrierConstructionAwardUpdateDto);
            // 申请审批
            if (bmsCarrierConstructionAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsCarrierConstructionAward bmsCarrierConstructionAward =new BmsCarrierConstructionAward();
                BeanUtil.copyProperties(bmsCarrierConstructionAwardUpdateDto, bmsCarrierConstructionAward);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(bmsCarrierConstructionAward));
                jP.setFileJson("{" +
                        '"' + "相关佐证资料" + '"' + ":" + '"' + bmsCarrierConstructionAward.getSupportingMaterials() + '"' + ','+
                        '"' + "项目工商登记许可" + '"' + ":" + '"' + bmsCarrierConstructionAward.getBusinessLicense() + '"' + ','+
                        '"' + "消防验收报告" + '"' + ":" + '"' + bmsCarrierConstructionAward.getFireReport() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除载体建设奖补
     * 
     * @param ids 需要删除的载体建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCarrierConstructionAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsCarrierConstructionAwardByIds(ids);
    }

    /**
     * 删除载体建设奖补信息
     * 
     * @param id 载体建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCarrierConstructionAwardById(Long id) {
        return baseMapper.deleteBmsCarrierConstructionAwardById(id);
    }
}
