package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsBrandingAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIndustrialInternetAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsIndustrialInternetAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsIndustrialInternetAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 5G+工业互联网奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsIndustrialInternetAwardServiceImpl extends ServiceImpl<BmsIndustrialInternetAwardMapper,BmsIndustrialInternetAward> implements IBmsIndustrialInternetAwardService {

    @Autowired
    private ICommonService iCommonService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询5G+工业互联网奖补
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 5G+工业互联网奖补
     */
    @Override
    public BmsIndustrialInternetAward selectBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.selectBmsIndustrialInternetAwardById(id);
    }

    /**
     * 查询5G+工业互联网奖补列表
     * 
     * @param bmsIndustrialInternetAward 5G+工业互联网奖补
     * @return 5G+工业互联网奖补
     */
    @Override
    public List<BmsIndustrialInternetAward> selectBmsIndustrialInternetAwardList(BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        return baseMapper.selectBmsIndustrialInternetAwardList(bmsIndustrialInternetAward);
    }

    /**
     * 新增5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardAddDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIndustrialInternetAward(BmsIndustrialInternetAwardAddDto bmsIndustrialInternetAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIndustrialInternetAwardAddDto.getTyshxydm()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIndustrialInternetAwardAddDto.getTyshxydm()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        BmsIndustrialInternetAward bmsIndustrialInternetAward = new BmsIndustrialInternetAward();
        BeanUtil.copyProperties(bmsIndustrialInternetAwardAddDto,bmsIndustrialInternetAward);
        bmsIndustrialInternetAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIndustrialInternetAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交5G+工业互联网奖补申请");
        declarationRecords.setDetailId(bmsIndustrialInternetAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsIndustrialInternetAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //获取某个在线记录id可以添加到项目库的数据
        JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsIndustrialInternetAwardAddDto.getDeclarationId());
        addProject.setStatus(1);
        addProject.setOtherJson(JSONObject.toJSONString(bmsIndustrialInternetAward));
        addProject.setFileJson("{" +
                '"' + "证明材料" + '"' + ":" + '"' + bmsIndustrialInternetAward.getMaterial() + '"' +
                "}");
        jProjectService.save(addProject);
        declarationRecords.setJjhProjectId(addProject.getId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
         iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }



    /**
     * 修改5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardUpdateDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIndustrialInternetAward(BmsIndustrialInternetAwardUpdateDto bmsIndustrialInternetAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsIndustrialInternetAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsIndustrialInternetAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIndustrialInternetAward(bmsIndustrialInternetAwardUpdateDto);
            // 申请审批
            if (bmsIndustrialInternetAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsIndustrialInternetAward bs =new BmsIndustrialInternetAward();
                BeanUtil.copyProperties(bmsIndustrialInternetAwardUpdateDto, bs);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(bs));
                jP.setFileJson("{" +
                        '"' + "证明材料" + '"' + ":" + '"' + bs.getMaterial() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除5G+工业互联网奖补
     * 
     * @param ids 需要删除的5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsIndustrialInternetAwardByIds(ids);
    }

    /**
     * 删除5G+工业互联网奖补信息
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.deleteBmsIndustrialInternetAwardById(id);
    }
}
