package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIntegrationIndustries;
import com.ruoyi.jjh.declaration.entity.BmsLogisticsDevelopmentAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsLogisticsDevelopmentAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsLogisticsDevelopmentAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsLogisticsDevelopmentAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 物流发展奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsLogisticsDevelopmentAwardServiceImpl extends ServiceImpl<BmsLogisticsDevelopmentAwardMapper,BmsLogisticsDevelopmentAward> implements IBmsLogisticsDevelopmentAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Autowired

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询物流发展奖补
     * 
     * @param id 物流发展奖补主键
     * @return 物流发展奖补
     */
    @Override
    public BmsLogisticsDevelopmentAward selectBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardById(id);
    }

    /**
     * 查询物流发展奖补列表
     * 
     * @param bmsLogisticsDevelopmentAward 物流发展奖补
     * @return 物流发展奖补
     */
    @Override
    public List<BmsLogisticsDevelopmentAward> selectBmsLogisticsDevelopmentAwardList(BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward) {
        return baseMapper.selectBmsLogisticsDevelopmentAwardList(bmsLogisticsDevelopmentAward);
    }

    /**
     * 新增物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardAddDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardAddDto bmsLogisticsDevelopmentAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsLogisticsDevelopmentAwardAddDto.getTyshxydm()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsLogisticsDevelopmentAwardAddDto.getTyshxydm()
                ,bmsLogisticsDevelopmentAwardAddDto.getTemplateRecordId());
        BmsLogisticsDevelopmentAward bmsLogisticsDevelopmentAward = new BmsLogisticsDevelopmentAward();

        BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardAddDto,bmsLogisticsDevelopmentAward);
        bmsLogisticsDevelopmentAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsLogisticsDevelopmentAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交物流发展奖补申请");
        declarationRecords.setStatus(1L);
        declarationRecords.setDetailId(bmsLogisticsDevelopmentAward.getId());
        declarationRecords.setId(bmsLogisticsDevelopmentAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //获取某个在线记录id可以添加到项目库的数据
        JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsLogisticsDevelopmentAwardAddDto.getDeclarationId());
        addProject.setStatus(1);
        addProject.setOtherJson(JSONObject.toJSONString(bmsLogisticsDevelopmentAward));
        addProject.setFileJson( "{" +
                '"' + "荣誉证明文件" + '"' + ":" + '"' + bmsLogisticsDevelopmentAward.getHonorCertificate() + '"' + ","+
                '"' + "平台名称" + '"' + ":" + '"' + bmsLogisticsDevelopmentAward.getPlatformName() + '"' + ","+
                '"' + "企业投资项目备案通知书或核准批复文件" + '"' + ":" + '"' + bmsLogisticsDevelopmentAward.getFilingNotice() + '"' + ","+
                '"' + "会计师事务所出具的企业财务报表审计报告" + '"' + ":" + '"' + bmsLogisticsDevelopmentAward.getAuditReport() + '"' +
                "}");
        jProjectService.save(addProject);
        declarationRecords.setJjhProjectId(addProject.getId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    /**
     * 修改物流发展奖补
     * 
     * @param bmsLogisticsDevelopmentAwardUpdateDto 物流发展奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsLogisticsDevelopmentAward(BmsLogisticsDevelopmentAwardUpdateDto bmsLogisticsDevelopmentAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsLogisticsDevelopmentAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            num = baseMapper.updateBmsLogisticsDevelopmentAward(bmsLogisticsDevelopmentAwardUpdateDto);
            // 申请审批
            if (bmsLogisticsDevelopmentAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsLogisticsDevelopmentAward p1 =new BmsLogisticsDevelopmentAward();
                BeanUtil.copyProperties(bmsLogisticsDevelopmentAwardUpdateDto, p1);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(p1));
                jP.setFileJson( "{" +
                        '"' + "荣誉证明文件" + '"' + ":" + '"' + p1.getHonorCertificate() + '"' + ","+
                        '"' + "平台名称" + '"' + ":" + '"' + p1.getPlatformName() + '"' + ","+
                        '"' + "企业投资项目备案通知书或核准批复文件" + '"' + ":" + '"' + p1.getFilingNotice() + '"' + ","+
                        '"' + "会计师事务所出具的企业财务报表审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsLogisticsDevelopmentAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除物流发展奖补
     * 
     * @param ids 需要删除的物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardByIds(ids);
    }

    /**
     * 删除物流发展奖补信息
     * 
     * @param id 物流发展奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsLogisticsDevelopmentAwardById(Long id) {
        return baseMapper.deleteBmsLogisticsDevelopmentAwardById(id);
    }
}
