package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsLogisticsDevelopmentAward;
import com.ruoyi.jjh.declaration.entity.BmsManufacturingServicesAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsManufacturingServicesAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsManufacturingServicesAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsManufacturingServicesAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsManufacturingServicesAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 制造服务业有效投入奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsManufacturingServicesAwardServiceImpl extends ServiceImpl<BmsManufacturingServicesAwardMapper,BmsManufacturingServicesAward> implements IBmsManufacturingServicesAwardService {

    @Autowired
    private ICommonService iCommonService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询制造服务业有效投入奖补
     * 
     * @param id 制造服务业有效投入奖补主键
     * @return 制造服务业有效投入奖补
     */
    @Override
    public BmsManufacturingServicesAward selectBmsManufacturingServicesAwardById(Long id) {
        return baseMapper.selectBmsManufacturingServicesAwardById(id);
    }

    /**
     * 查询制造服务业有效投入奖补列表
     * 
     * @param bmsManufacturingServicesAward 制造服务业有效投入奖补
     * @return 制造服务业有效投入奖补
     */
    @Override
    public List<BmsManufacturingServicesAward> selectBmsManufacturingServicesAwardList(BmsManufacturingServicesAward bmsManufacturingServicesAward) {
        return baseMapper.selectBmsManufacturingServicesAwardList(bmsManufacturingServicesAward);
    }

    /**
     * 新增制造服务业有效投入奖补
     * 
     * @param bmsManufacturingServicesAwardAddDto 制造服务业有效投入奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsManufacturingServicesAward(BmsManufacturingServicesAwardAddDto bmsManufacturingServicesAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsManufacturingServicesAwardAddDto.getTyshxydm()
                ,bmsManufacturingServicesAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsManufacturingServicesAwardAddDto.getTyshxydm()
                ,bmsManufacturingServicesAwardAddDto.getTemplateRecordId());
        BmsManufacturingServicesAward bmsManufacturingServicesAward = new BmsManufacturingServicesAward();
        BeanUtil.copyProperties(bmsManufacturingServicesAwardAddDto,bmsManufacturingServicesAward);
        bmsManufacturingServicesAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsManufacturingServicesAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交制造服务业有效投入奖补申请");
        declarationRecords.setDetailId(bmsManufacturingServicesAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsManufacturingServicesAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        //获取某个在线记录id可以添加到项目库的数据
        JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsManufacturingServicesAwardAddDto.getDeclarationId());
        addProject.setStatus(1);
        addProject.setOtherJson(JSONObject.toJSONString(bmsManufacturingServicesAward));
        addProject.setFileJson( "{" +
                '"' + "企业投资项目备案通知书或核准批复文件" + '"' + ":" + '"' + bmsManufacturingServicesAward.getFilingNotice() + '"' + ","+
                '"' + "购置设备发票清单及发票扫描件" + '"' + ":" + '"' + bmsManufacturingServicesAward.getInvoice() + '"' + ","+
                '"' + "会计师事务所出具的企业申报项目购置设备情况的专项审计报告" + '"' + ":" + '"' + bmsManufacturingServicesAward.getAuditReport() + '"' + ","+
                '"' + "会计师事务所出具的企业财务报表审计报告" + '"' + ":" + '"' + bmsManufacturingServicesAward.getFinancialStatements() + '"' +
                "}");
        jProjectService.save(addProject);
        declarationRecords.setJjhProjectId(addProject.getId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    /**
     * 修改制造服务业有效投入奖补
     * 
     * @param bmsManufacturingServicesAwardUpdateDto 制造服务业有效投入奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsManufacturingServicesAward(BmsManufacturingServicesAwardUpdateDto bmsManufacturingServicesAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsManufacturingServicesAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsManufacturingServicesAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsManufacturingServicesAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num =  baseMapper.updateBmsManufacturingServicesAward(bmsManufacturingServicesAwardUpdateDto);
            // 申请审批
            if (bmsManufacturingServicesAwardUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsManufacturingServicesAward p1 =new BmsManufacturingServicesAward();
                BeanUtil.copyProperties(bmsManufacturingServicesAwardUpdateDto, p1);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsManufacturingServicesAwardUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(p1));
                jP.setFileJson( "{" +
                        '"' + "企业投资项目备案通知书或核准批复文件" + '"' + ":" + '"' + p1.getFilingNotice() + '"' + ","+
                        '"' + "购置设备发票清单及发票扫描件" + '"' + ":" + '"' + p1.getInvoice() + '"' + ","+
                        '"' + "会计师事务所出具的企业申报项目购置设备情况的专项审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' + ","+
                        '"' + "会计师事务所出具的企业财务报表审计报告" + '"' + ":" + '"' + p1.getFinancialStatements() + '"' +
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsManufacturingServicesAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除制造服务业有效投入奖补
     * 
     * @param ids 需要删除的制造服务业有效投入奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsManufacturingServicesAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsManufacturingServicesAwardByIds(ids);
    }

    /**
     * 删除制造服务业有效投入奖补信息
     * 
     * @param id 制造服务业有效投入奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsManufacturingServicesAwardById(Long id) {
        return baseMapper.deleteBmsManufacturingServicesAwardById(id);
    }
}
