package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.*;
import com.ruoyi.jjh.declaration.entity.dto.BmsBigStrongAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsBigStrongAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsOutQuitProductsAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsOutQuitProductsUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsOutQuitProductsMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsOutQuitProductsService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 2024年度淘汰落后和退出低端低效产能装备清单Service业务层处理
 *
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsOutQuitProductsServiceImpl extends ServiceImpl<BmsOutQuitProductsMapper,BmsOutQuitProducts> implements IBmsOutQuitProductsService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询2024年度淘汰落后和退出低端低效产能装备清单列表
     *
     * @param bmsOutQuitProducts 详情
     * @return 详情集合
     */
    @Override
    public List<BmsOutQuitProducts> selectBmsOutQuitProductsList(BmsOutQuitProducts bmsOutQuitProducts) {
        return baseMapper.selectBmsOutQuitProductsList(bmsOutQuitProducts);
    }

    /**
     * 新增2024年度淘汰落后和退出低端低效产能装备清单
     *
     * @param bmsOutQuitProductsAddDto 详情
     * @return 结果
     */
    @Override
    public int insertBmsOutQuitProducts(BmsOutQuitProductsAddDto bmsOutQuitProductsAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsOutQuitProductsAddDto.getTyshxydm()
                ,bmsOutQuitProductsAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsOutQuitProductsAddDto.getTyshxydm()
                ,bmsOutQuitProductsAddDto.getTemplateRecordId());

        BmsOutQuitProducts products = new BmsOutQuitProducts();
        BeanUtil.copyProperties(bmsOutQuitProductsAddDto,products);
        products.setEnterpriseId(enterpriseId);
        int num = baseMapper.insert(products);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交2024年度淘汰落后和退出低端低效产能装备清单");
        declarationRecords.setDetailId(products.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsOutQuitProductsAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //获取某个在线记录id可以添加到项目库的数据
        JProject addProject = iBmsDeclarationRecordsService.getAddProject(bmsOutQuitProductsAddDto.getDeclarationId());
        addProject.setStatus(1);

        if(products.getIndustry() == 1){
            products.setNewIndustry("轻工");
        }else if(products.getIndustry() == 2){
            products.setNewIndustry("纺织");
        }else if(products.getIndustry() == 3){
            products.setNewIndustry("冶金");
        }else if(products.getIndustry() == 4){
            products.setNewIndustry("化工");
        }else if(products.getIndustry() == 5){
            products.setNewIndustry("建材");
        }else if(products.getIndustry() == 6){
            products.setNewIndustry("机械加工");
        }
        if(products.getType() == 1){
            products.setNewType("淘汰落后生产工艺装备");
        }else{
            products.setNewType("退出低端低效生产工艺装备");
        }
        addProject.setOtherJson(JSONObject.toJSONString(products));
        addProject.setFileJson( "{" +
                '"' + "拟淘汰或退出生产工艺装备情况" + '"' + ":" + '"' + products.getSpecifics() + '"' + "," +
                '"' + "其他相关情况说明" + '"' + ":" + '"' + products.getOtherSpecifics() + '"'+
                "}");
        jProjectService.save(addProject);
        declarationRecords.setJjhProjectId(addProject.getId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public int updateBmsOutQuitProducts(BmsOutQuitProductsUpdateDto bmsOutQuitProductsUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsOutQuitProductsUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsOutQuitProductsUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            num = baseMapper.updateById(bmsOutQuitProductsUpdateDto);
            // 申请审批
            if (bmsOutQuitProductsUpdateDto.getStatus()==1){
                JProject jP = new JProject();
                BmsOutQuitProducts p1 =new BmsOutQuitProducts();
                BeanUtil.copyProperties(bmsOutQuitProductsUpdateDto, p1);
                jP.setId(iBmsDeclarationRecordsService.getById(bmsOutQuitProductsUpdateDto.getDeclarationRecordsId()).getJjhProjectId());
                jP.setStatus(1);
                jP.setOtherJson(JSONObject.toJSONString(p1));
                jP.setFileJson("{" +
                        '"' + "拟淘汰或退出生产工艺装备情况" + '"' + ":" + '"' + p1.getSpecifics() + '"' + "," +
                        '"' + "其他相关情况说明" + '"' + ":" + '"' + p1.getOtherSpecifics() + '"'+
                        "}");
                //修改项目
                jProjectService.updateById(jP);
                // 审批状态
                iCommonService.updateAuditRecord(bmsOutQuitProductsUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }
    /**
     * 批量删除2024年度淘汰落后和退出低端低效产能装备清单
     *
     * @param ids 主键集合
     * @return 结果
     */
    @Override
    public int deleteBmsOutQuitProductsByIds(Long[] ids) {
        return baseMapper.deleteBmsOutQuitProductsByIds(ids);
    }

    /**
     * 删除2024年度淘汰落后和退出低端低效产能装备清单
     *
     * @param id 详情主键
     * @return 结果
     */
    @Override
    public int deleteBmsOutQuitProductsById(Long id) {
        return baseMapper.deleteBmsOutQuitProductsById(id);
    }
}
